audonnx
=======

.. automodule:: audonnx


load
----

.. autofunction:: load


Model
-----

.. autoclass:: Model
    :members:
    :special-members: __call__


InputNode
---------

.. autoclass:: InputNode
    :members:


OutputNode
----------

.. autoclass:: OutputNode
    :members:
